@@ -179,11 +179,54 @@ class AIHClient:
             raise AIHE.AIHClientException(f'DELETE request failed: {response.status_code}\n{response.text}')
         
             
-        
-        
-    def get_file(self, container:str, name:str):
+    def download_file(self, file_id:str):
         """
-        To get download a file.
+        download_file downloads the file from DataUpload API.
+        
+        IN: file_id (str) - The id for the file to download.
+        
+        OUT: (content) - The response content.
+        """
+        
+        if(self.is_expired()):
+            self.update_token()
+        
+        url = f'https://{self.environment}-du-we-api.azurewebsites.net/files/download/{file_id}'
+        response = self.client.get(url)
+
+        return response.content
+
+        
+    def upload_file(self, datatype_id:str, file, name:str):
+        """
+        upload_file uploads a file for a DataType to the DataUpload API.
+
+        IN: datatype_id (str) - The id of the DataType to uplaod the file to.
+            file (bytes)      - The bytes for the file to upload.
+            name (str)        - The name the file should be stored as. The name must include the file extension.
+
+        OUT: (json) - The json response
+        """
+
+        if(self.is_expired()):
+            self.update_token()
+        
+        fileextension = name.split('.')[-1]
+        url = f'https://{self.environment}-du-we-api.azurewebsites.net/Files'
+        files = {
+            'Id' : (None, ''),
+            'DataTypeId' : (None, datatype_id),
+            'File' : (name, file, f'image/{fileextension}')
+        } 
+        
+        response = self.client.post(url=url, files=files)
+        
+        return response.json()
+
+
+    def download_media(self, container:str, name:str):
+        """
+        To get download a file from the media objects.
         IN: container (str) - To specify the type of file to donwload e.g. image
             name (str) - To specify the name of the file to download
             
@@ -197,11 +240,17 @@ class AIHClient:
                 
         return response.content
 
+    
 
-
-    def upload_file(self, container, file, name):
+    def upload_media(self, container, file, name):
         """
-        todo
+        upload_file uploads a file to a data type.
+
+        IN: datatype_id (str) - The id of the DataType to uplaod the file to.
+            file (bytes)      - The bytes for the file to upload.
+            name (str)        - The name the file should be stored as. The name must include the file extension.
+
+        OUT: (json) - The json response
         """
         
         if(self.is_expired()):
